/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CopyFilesDialog.h"

#include "BaseIconNames.h"
#include "IconEngine.h"
#include "TreeView.h"
#include "XmlOptions.h"

#include <QHeaderView>
#include <QLabel>
#include <QLayout>
#include <QScrollBar>

#include <numeric>

//____________________________________________________________________________
CopyFilesDialog::CopyFilesDialog( QWidget* parent, const FileInfo::List& files, const File& destination ):
    QuestionDialog( parent ),
    model_( this )
{

    Debug::Throw( "CopyFilesDialog::CopyFilesDialog.\n" );

    // option name
    setOptionName( "COPY_FILES_DIALOG" );

    // customize buttons
    okButton().setText( tr( "Copy" ) );
    okButton().setIcon( IconEngine::get( IconNames::Copy ) );

    // label
    setText( tr( "Copy %1 to folder %2" ).arg(
        FileInfo::Description( FileInfo::Description::Designate | FileInfo::Description::LowerCase ).get( files ),
        destination ) );

    auto treeView( new TreeView( this ) );
    treeView->setSelectionMode( QAbstractItemView::NoSelection );

    model_.setShowIcons( false );
    model_.add( files );
    model_.sort( FileInfoModel::FileName, Qt::DescendingOrder );

    // setup list
    treeView->setModel( &model_ );
    treeView->toggleShowHeader( false );
    treeView->setMask( 1<<FileInfoModel::FileName );
    treeView->header()->setSortIndicator( FileInfoModel::FileName, Qt::AscendingOrder );

    // resize list to accomodate longest item
    const auto maxWidth = std::accumulate( files.begin(), files.end(), 0,
        [&treeView](int maxWidth, const FileInfo& fileInfo )
        { return qMax( maxWidth, treeView->fontMetrics().width( fileInfo.file() ) ); } );

    treeView->verticalScrollBar()->adjustSize();
    treeView->setMinimumSize( QSize(
        maxWidth + treeView->verticalScrollBar()->width() + 10,
        treeView->fontMetrics().height() + 10 ) );

    setDetails( treeView );

}
