/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FtpCommand.h"
#include "CppUtil.h"


namespace Ftp
{

    #if QT_VERSION < 0x040800
    //_________________________________________
    Command::Command( Type type, std::initializer_list<FileInfo>&& arguments ):
        Command( type, Base::makeT<FileInfo::List>( std::move( arguments ) ) )
    {}
    #endif

    //_________________________________________
    const Command::NameMap& Command::_names()
    {
        static const auto names = Base::makeT<NameMap>(
        {
            { Type::None, QObject::tr( "none" )},
            { Type::ConnectToHost, QObject::tr( "connect to host" )},
            { Type::Login, QObject::tr( "login" )},
            { Type::Close, QObject::tr( "close connection" )},
            { Type::ShowDirectory, QObject::tr( "list remote files" )},
            { Type::ChangeDirectory, QObject::tr( "change directory" )},
            { Type::CreateDirectory, QObject::tr( "create directory" )},
            { Type::Copy, QObject::tr( "copy selected files" )},
            { Type::Remove, QObject::tr( "remove files" )},
            { Type::Rename, QObject::tr( "rename file" )},
        });

        return names;
    }

    //___________________________________________________________________
    int& Command::_counter()
    {
        static int counter( 0 );
        return counter;
    }

    //_______________________________________
    Command::Command( Command::Type type, FileInfo::List&& arguments ):
        Counter( "Ftp::Command" ),
        id_( _counter()++ ),
        type_( type ),
        arguments_( std::move(arguments) )
    {}

}
