#ifndef FtpCommandModel_h
#define FtpCommandModel_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "ListModel.h"
#include "FtpCommand.h"

#include <QHash>

#include <array>


namespace Ftp
{
    class CommandModel : public ListModel<Command>, private Base::Counter<CommandModel>
    {

        //* Qt meta object declaration
        Q_OBJECT

        public:

        //* constructor
        explicit CommandModel( QObject* = nullptr );

         //* column type enumeration
         enum ColumnType
        {
            Name,
            FileName,
            nColumns
        };

        //*@name methods reimplemented from base class
        //@{

        //* data
        QVariant data( const QModelIndex&, int ) const override;

        //* header data
        QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const override;

        //* number of columns for a given index
        int columnCount( const QModelIndex& = QModelIndex() ) const override
        { return nColumns; }

        //@}

        public Q_SLOTS:

        //* add command
        void add( const Ftp::Command& command )
        { ListModel<Command>::add( command ); }

        //* add commands
        void add( const Ftp::Command::List& commands )
        { ListModel<Command>::add( commands ); }

        //* remove
        void remove( const Ftp::Command& command )
        { ListModel<Command>::remove( command ); }

        private Q_SLOTS:

        //* update configuration
        void _updateConfiguration();

        private:

        //* install pixmaps
        void _installIcons() const;

        //* list column names
        const std::array<QString, nColumns> columnTitles_ =
        {{
            tr( "Command" ),
            tr( "File" )
        }};

        //* icon cache
        using IconCache = QHash<Command::Type, QIcon>;

        //* type icon cache for local modifications
        static IconCache& _icons();

    };

}

#endif
