/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "FtpMacro.h"
#include "CppUtil.h"

namespace Ftp
{

    #if QT_VERSION < 0x040800
    //___________________________________________________________________
    Macro::Macro( Type type, std::initializer_list<FileInfo>&& arguments ):
            Macro( type, Base::makeT<FileInfo::List>( std::move( arguments ) ) )
    {}
    #endif

    //___________________________________________________________________
    const Macro::NameMap& Macro::_names()
    {
        static const auto names = Base::makeT<NameMap>(
        {
            { Type::None, QObject::tr( "none" ) },
            { Type::Connect, QObject::tr( "connect to host" ) },
            { Type::CloseConnection, QObject::tr( "close connection" ) },
            { Type::Add, QObject::tr( "add file to internal list" ) },
            { Type::Clear, QObject::tr( "clear internal file list" ) },
            { Type::Abort, QObject::tr( "abort transfer" ) },
            { Type::CopyRecursive, QObject::tr( "copy selected items" ) },
            { Type::CreateDirectory, QObject::tr( "create directory" ) },
            { Type::Rename, QObject::tr( "rename selected item" ) },
            { Type::Remove, QObject::tr( "remove selected items" ) },
            { Type::Open, QObject::tr( "open files" ) },
            { Type::ShowDirectory, QObject::tr( "query directory content" ) },
            { Type::ListRecursive, QObject::tr( "query directory content (recursive)" ) },
            { Type::SizeRecursive, QObject::tr( "query directory size (recursive)" ) },
            { Type::CheckConflicts, QObject::tr( "check file conflicts" ) },
            { Type::CheckFilesCopy, QObject::tr( "check file transfer (copy)" ) },
            { Type::CheckFilesMoved, QObject::tr( "check file transfer (move)" ) },
            { Type::CheckFilesExist, QObject::tr( "check file existence" ) },
            { Type::ClearSelection, QObject::tr( "clear display selection" ) },
            { Type::Select, QObject::tr( "update display selection" ) }
        });

        return names;
    }

    //___________________________________________________________________
    int& Macro::_counter()
    {
        static int counter( 0 );
        return counter;
    }

    //_________________________________________
    Macro::Macro( Type type, FileInfo::List&& arguments ):
        Counter( "Ftp::Macro" ),
        id_( _counter()++ ),
        type_( type ),
        arguments_( std::move( arguments ) )
    {}

}
