/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "RenameFileDialog.h"

#include "LineEditor.h"
#include "XmlOptions.h"

#include <QLabel>
#include <QLayout>

//____________________________________________________________________________
RenameFileDialog::RenameFileDialog( QWidget* parent, const FileInfo& fileInfo ):
    CustomDialog( parent ),
    fileInfo_( fileInfo )
{

    Debug::Throw( "RenameFileDialog::RenameFileDialog.\n" );

    // option name
    setOptionName( "RENAME_FILE_DIALOG" );

    // customize buttons
    okButton().setText( tr( "Rename" ) );

    // local file
    const File localFile( fileInfo.file().localName() );

    // label
    const auto buffer = tr( "Rename item '%1' to:" ).arg( localFile );
    auto textLabel( new QLabel( buffer, this ) );
    mainLayout().addWidget( textLabel );

    // editor
    mainLayout().addWidget( editor_ = new LineEditor( this ) );
    textLabel->setBuddy( editor_ );

    // set text and selection
    editor().setText( localFile );
    editor().setFocus();

    // get short name and select
    File shortFile( localFile.truncatedName() );
    if( !shortFile.isEmpty() ) editor().setSelection( 0, shortFile.get().size() );
    else editor().selectAll();

    connect( editor_, SIGNAL(textChanged(QString)), SLOT(_updateButtons()) );

    _updateButtons();

}

//____________________________________________________________________________
void RenameFileDialog::_updateButtons()
{ okButton().setEnabled( !( editor().text().trimmed().isEmpty() || editor().text().trimmed() == fileInfo_.file().localName() ) ); }
