/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ViewModeMenu.h"

#include "Application.h"
#include "CppUtil.h"
#include "Debug.h"
#include "FileSelectionFrame.h"
#include "IconNames.h"
#include "IconEngine.h"
#include "MainWindow.h"

//_____________________________________________
ViewModeMenu::ViewModeMenu( QWidget* parent ):
    QMenu( parent ),
    Counter( "ViewModeMenu" )
{
    Debug::Throw( "ViewModeMenu::ViewModeMenu.\n" );
    auto actionGroup = new QActionGroup( this );
    actions_ = Base::makeT<ActionMap>(
    {
        { addAction( IconEngine::get( IconNames::IconsView ), tr( "Icons" ) ), FileSelectionFrame::ViewMode::Icons },
        { addAction( IconEngine::get( IconNames::DetailsView ), tr( "Details" ) ), FileSelectionFrame::ViewMode::Details }
    } );

    for( auto&& iter = actions_.begin(); iter != actions_.end(); ++iter )
    {
        iter.key()->setCheckable( true );
        actionGroup->addAction( iter.key() );
    }

    connect( this, SIGNAL(aboutToShow()), SLOT(_update()) );
    connect( this, SIGNAL(triggered(QAction*)), SLOT(_selectViewMode(QAction*)) );
}

//_____________________________________________
void ViewModeMenu::_update()
{
    Debug::Throw( "ViewModeMenu::_update.\n" );

    // retrieve current class from MainWindow
    auto window( static_cast<MainWindow*>( parentWidget()->window()) );
    const auto viewMode( window->activeFrame().viewMode() );
    for( auto&& iter = actions_.begin(); iter != actions_.end(); ++iter )
    { iter.key()->setChecked( viewMode == iter.value() ); }

}

//_____________________________________________
void ViewModeMenu::_selectViewMode( QAction* action )
{
    Debug::Throw( "ViewModeMenu::_selectViewMode.\n" );
    ActionMap::iterator iter = actions_.find( action );
    if( iter != actions_.end() )
    { emit viewModeSelected( iter.value() ); }

    return;

}
